@@ -2,13 +2,13 @@
 function(data) {
    lmom <- lmom.ub(data)
    para <- pargam(lmom)
-   print("GAMMA DISTRIBUTION PARAMETERS")
-   print(para)
+   cat("GAMMA DISTRIBUTION PARAMETERS\n")
+   str(para)
    lmompara <- lmomgam(para)
    Q50 <- quagam(0.5,para)
-   print(c('MEDIAN ',Q50))
+   cat(c("Computed median=",Q50,"\n"),sep="")
    P50 <- cdfgam(Q50,para)
-   print(c('NONEXCEEDANCE OF COMPUTED MEDIAN ',P50))
+   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
    lmom.diff(lmompara,lmom)
 }
 
