@@ -9,7 +9,7 @@ function(para) {
               L3   = NULL,
               L4   = NULL,
               L5   = NULL,
-              source = "lmompe3--ordinary"
+              source = "lmompe3"
              )
 
     if(! are.parpe3.valid(para)) return()
